pub fn create_depth_texture(
device: &Device,
width: u32,
height: u32,
) -> TextureViewExpand description
Create a depth texture for the given surface dimensions.
pub fn create_depth_texture(
device: &Device,
width: u32,
height: u32,
) -> TextureViewCreate a depth texture for the given surface dimensions.