Module mesh

Module mesh 

Tile mesh generation for GPU rendering.

Structs

TileMesh
Generated mesh data for a single tile quad.

Functions

build_tile_mesh
Build a tile quad mesh in world space, then offset relative to a camera origin to avoid floating-point precision issues far from the origin.