pub struct PainterPlan { /* private fields */ }Expand description
Renderer pass plan for one frame.
Implementations
Sourceimpl PainterPlan
impl PainterPlan
Sourcepub fn new(
has_terrain_data: bool,
has_hillshade_overlay: bool,
has_heatmap: bool,
) -> Self
pub fn new( has_terrain_data: bool, has_hillshade_overlay: bool, has_heatmap: bool, ) -> Self
Build the pass plan for the current frame.
Sourcepub fn with_shadows(
has_terrain_data: bool,
has_hillshade_overlay: bool,
has_heatmap: bool,
has_shadows: bool,
) -> Self
pub fn with_shadows( has_terrain_data: bool, has_hillshade_overlay: bool, has_heatmap: bool, has_shadows: bool, ) -> Self
Build the pass plan, optionally including shadow depth passes.
Sourcepub fn iter(&self) -> impl Iterator<Item = PainterPass> + '_
pub fn iter(&self) -> impl Iterator<Item = PainterPass> + '_
Iterate passes in execution order.
Sourcepub fn contains(&self, pass: PainterPass) -> bool
pub fn contains(&self, pass: PainterPass) -> bool
Whether a specific pass is present in this frame plan.