VisualizationPerfStats

Struct VisualizationPerfStats 

pub struct VisualizationPerfStats {
    pub grid_scalar_rebuilds: u32,
    pub grid_scalar_value_updates: u32,
    pub grid_extrusion_rebuilds: u32,
    pub grid_extrusion_value_updates: u32,
    pub column_rebuilds: u32,
    pub column_partial_writes: u32,
    pub column_partial_write_ranges: u32,
    pub point_cloud_rebuilds: u32,
    pub point_cloud_partial_writes: u32,
    pub point_cloud_partial_write_ranges: u32,
}
Per-frame visualization cache activity recorded during the last render.

Fields

grid_scalar_rebuilds: u32

Number of grid-scalar overlay cache rebuilds.

grid_scalar_value_updates: u32

Number of grid-scalar value-texture updates.

grid_extrusion_rebuilds: u32

Number of grid-extrusion overlay rebuilds.

grid_extrusion_value_updates: u32

Number of grid-extrusion vertex-buffer updates.

column_rebuilds: u32

Number of column overlay rebuilds.

column_partial_writes: u32

Number of partial column buffer writes.

column_partial_write_ranges: u32

Number of changed contiguous column ranges written this frame.

point_cloud_rebuilds: u32

Number of point-cloud overlay rebuilds.

point_cloud_partial_writes: u32

Number of point-cloud partial retained writes.

point_cloud_partial_write_ranges: u32

Number of changed contiguous point-cloud ranges written this frame.